@@ -24,6 +24,7 @@ from qgis_deployment_toolbelt.jobs.job_profiles_synchronizer import (
     JobProfilesDownloader,
 )
 from qgis_deployment_toolbelt.jobs.job_shortcuts import JobShortcutsManager
+from qgis_deployment_toolbelt.jobs.job_splash_screen import JobSplashScreenManager
 
 # #############################################################################
 # ########## Globals ###############
@@ -40,7 +41,12 @@ logger = logging.getLogger(__name__)
 class JobsOrchestrator:
     """Orchestrate jobs."""
 
-    JOBS = (JobEnvironmentVariables, JobProfilesDownloader, JobShortcutsManager)
+    JOBS = (
+        JobEnvironmentVariables,
+        JobProfilesDownloader,
+        JobShortcutsManager,
+        JobSplashScreenManager,
+    )
     PACKAGE_NAME: str = "qgis_deployment_toolbelt.jobs"
 
     def __init__(self) -> None:
